CapabilitySet
=============

.. currentmodule:: atqo

.. autoclass:: CapabilitySet
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~CapabilitySet.total_resource_use

   .. rubric:: Attributes Documentation

   .. autoattribute:: total_resource_use
